==> haskell-email-validate-2.3.2.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.8
id: email-validate-2.3.2.8-GBW5GiX7hfUJXKjLaonqaT
key: email-validate-2.3.2.8-GBW5GiX7hfUJXKjLaonqaT
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 4dce2a4e5d4b4a01b752c11bf2ed26b1
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.1/site-local/email-validate-2.3.2.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/email-validate-2.3.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/email-validate-2.3.2.8
hs-libraries: HSemail-validate-2.3.2.8-GBW5GiX7hfUJXKjLaonqaT
depends:
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.8-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.8
id: email-validate-2.3.2.8-CWzslVpgH7s5KiDNbdRJke
key: email-validate-2.3.2.8-CWzslVpgH7s5KiDNbdRJke
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: b64f4edad638b311cc9249281a639112
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.1/site-local/email-validate-2.3.2.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/email-validate-2.3.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/email-validate-2.3.2.8
hs-libraries: HSemail-validate-2.3.2.8-CWzslVpgH7s5KiDNbdRJke
depends:
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
